@@ -158,7 +158,7 @@ class WebService(BaseDeployment):
         return super().get_params()
 
     @BaseDeployment._project_to_space_to_project
-    def score(self, payload: 'DataFrame') -> Dict[str, List]:
+    def score(self, payload: 'DataFrame', transaction_id: str = None) -> Dict[str, List]:
         """
         Online scoring on WML. Payload is passed to the WML scoring endpoint where model have been deployed.
 
@@ -167,6 +167,9 @@ class WebService(BaseDeployment):
         payload: pandas.DataFrame, required
             DataFrame with data to test the model.
 
+        transaction_id: str, optional
+            Can be used to indicate under which id the records will be saved into payload table in IBM OpenScale.
+
         Returns
         -------
         Dictionary with list od model output/predicted targets.
@@ -182,7 +185,7 @@ class WebService(BaseDeployment):
                               ['no', [0.9798324002736079, 0.020167599726392187]]
                 }]}
         """
-        return super().score(payload=payload)
+        return super().score(payload=payload, transaction_id=transaction_id)
 
     @BaseDeployment._project_to_space_to_project
     def delete(self, deployment_id: str = None) -> None:
