@@ -21,7 +21,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
     Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
     NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
-    TSNotSupported
+    TSNotSupported, ParamOutOfRange
 from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions, \
     validate_additional_params_for_optimizer, validate_optimizer_enum_values
 from ibm_watson_machine_learning.workspace import WorkSpace
@@ -165,6 +165,7 @@ class AutoAI(BaseExperiment):
                   drop_duplicates: bool = True,
                   text_processing: bool = None,
                   word2vec_feature_number: int = None,
+                  daub_give_priority_to_runtime: float = None,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -271,6 +272,11 @@ class AutoAI(BaseExperiment):
             Number of features which will be generated from text column. Will be applied only if `text_processing`
             is True. If `None` the default value will be taken.
 
+        daub_give_priority_to_runtime: float, optional
+            The importance of run time over score for pipelines ranking. Can take values between 0 and 5.
+            If set to 0.0 only score is used. If set to 1 equally score and runtime are used.
+            If set to value higher than 1 the runtime gets higher importance over score.
+
         Returns
         -------
         RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
@@ -337,6 +343,10 @@ class AutoAI(BaseExperiment):
             t_shirt_size=kwargs.get("t_shirt_size", TShirtSize.M)
         )
 
+        if daub_give_priority_to_runtime is not None:
+            if daub_give_priority_to_runtime < 0.0 or daub_give_priority_to_runtime > 5.0:
+                raise ParamOutOfRange('daub_give_priority_to_runtime', daub_give_priority_to_runtime, 0.0, 5.0)
+
         if data_join_graph:
             data_join_graph.problem_type = prediction_type
             data_join_graph.target_column = prediction_column
@@ -424,6 +434,7 @@ class AutoAI(BaseExperiment):
                 positive_label=positive_label,
                 data_join_only=data_join_only,
                 engine=engine,
+                daub_give_priority_to_runtime=daub_give_priority_to_runtime,
                 notebooks=kwargs.get('notebooks', True),
                 autoai_pod_version=kwargs.get('autoai_pod_version', None),
                 obm_pod_version=kwargs.get('obm_pod_version', None),
