@@ -24,7 +24,8 @@ from lomond import WebSocket
 from ibm_watson_machine_learning.utils.autoai.enums import (
     PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import PipelineNotLoaded, FitNeeded, InvalidPredictionType, \
-    AutoAIComputeError, ForecastingUnsupportedOperation, NoAvailableMetrics, LibraryNotCompatible
+    AutoAIComputeError, ForecastingUnsupportedOperation, NoAvailableMetrics, LibraryNotCompatible, \
+    CannotConnectToWebsocket
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.utils.autoai.progress_bar import ProgressBar
 from ibm_watson_machine_learning.utils.autoai.utils import (
@@ -428,10 +429,12 @@ class WMLEngine(BaseEngine):
             base_url = self._wml_client.service_instance._href_definitions.get_trainings_href()
             url = f"{base_url.replace('https', 'wss')}/{self._current_run_id}"
 
+            params = self._wml_client._params()
+
             if self._wml_client.default_project_id:
-                url = f"{url}?project_id={self._wml_client.default_project_id}"
+                url = f"{url}?project_id={self._wml_client.default_project_id}&version={params.get('version')}"
             elif self._wml_client.default_space_id:
-                url = f"{url}?space_id={self._wml_client.default_space_id}"
+                url = f"{url}?space_id={self._wml_client.default_space_id}&version={params.get('version')}"
 
             gen = ProgressGenerator()
             end = False
@@ -440,6 +443,9 @@ class WMLEngine(BaseEngine):
 
             progress_bar.set_description(desc='Started waiting for resources')
 
+            attempts_no = 10
+            disconnection_no = 0
+
             while not end:
                 websocket = WebSocket(url)
                 websocket.add_header(bytes("Authorization", "utf-8"),
@@ -503,17 +509,21 @@ class WMLEngine(BaseEngine):
                             elif process:
                                 progress_bar.increment_counter(gen.get_progress(process))
                                 progress_bar.update()
-                        elif event.name in ['closing']:
+                        elif event.name in ['closing', 'closed']:
                             end = True
                             websocket.close()
                             break
                         elif event.name in ['disconnected']:
+                            disconnection_no += 1
                             websocket.close()
                             break
                 except:
                     websocket.close()
                     break
 
+                if disconnection_no >= attempts_no:
+                    raise CannotConnectToWebsocket(attempts_no)
+
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
 
     def get_run_status(self) -> str:
