@@ -188,7 +188,7 @@ class BaseDataConnection(ABC):
 
             else:
                 items = self.location.href.split('/')
-            _id = items[3].split('?')[0]
+            _id = items[-1].split('?')[0]
 
             if self._wml_client is not None:
                 data_asset_details = self._wml_client.data_assets.get_details(_id)
