@@ -144,6 +144,7 @@ class DataConnection(BaseDataConnection):
 
         self.auto_pipeline_params = {}  # note: needed parameters for recreation of autoai holdout split
         self._wml_client = None
+        self.__wml_client = None    # only for getter/setter for AssetLocation href
         self._run_id = None
         self._obm = False
         self._obm_cos_path = None
@@ -162,6 +163,18 @@ class DataConnection(BaseDataConnection):
             self.id = data_join_node_name
         # --- end note
 
+    # note: client as property and setter for dynamic href creation for AssetLocation
+    @property
+    def _wml_client(self):
+        return self.__wml_client
+
+    @_wml_client.setter
+    def _wml_client(self, var):
+        self.__wml_client = var
+        if isinstance(self.location, (AssetLocation, WSDAssetLocation)):
+            self.location.wml_client = self.__wml_client
+    # --- end note
+
     @classmethod
     def from_studio(cls, path: str) -> List['DataConnection']:
         """
@@ -251,7 +264,7 @@ class DataConnection(BaseDataConnection):
             _dict['connection'] = {}
 
         try:
-            _dict['location'] = deepcopy(self.location.to_dict(self._wml_client))
+            _dict['location'] = deepcopy(self.location.to_dict())
 
         except AttributeError:
             _dict['location'] = {}
@@ -786,6 +799,7 @@ class AssetLocation(BaseLocation):
         self._wsd = self._is_wsd()
         self.href = None
         self._initial_asset_id = asset_id
+        self.__wml_client = None
 
         if self._wsd:
             self._asset_name = None
@@ -844,7 +858,9 @@ class AssetLocation(BaseLocation):
 
     @classmethod
     def _set_path(cls, href: str) -> 'AssetLocation':
-        location = cls('.')
+        items = href.split('/')
+        _id = items[-1].split('?')[0]
+        location = cls(_id)
         location.href = href
         return location
 
@@ -918,35 +934,42 @@ class AssetLocation(BaseLocation):
         project = get_project()
         return project.get_files()
 
-    def to_dict(self, wml_client=None) -> dict:
+    def to_dict(self) -> dict:
         """Return a json dictionary representing this model."""
         _dict = vars(self).copy()
 
         del _dict['_wsd']
+        del _dict[f"_{self.__class__.__name__}__wml_client"]
 
         if self._wsd:
             del _dict['_asset_name']
             del _dict['_asset_id']
             del _dict['_local_asset_path']
 
-        if self.href is None:
-            if wml_client:
-                _dict['href'] = wml_client.service_instance._href_definitions.get_base_asset_href(
-                    self._initial_asset_id)
-            else:
-                _dict['href'] = f'/v2/assets/{self._initial_asset_id}'
-
-            if not self._wsd:
-                if wml_client:
-                    if wml_client.default_space_id:
-                        _dict['href'] = f'{_dict["href"]}?space_id={wml_client.default_space_id}'
-                    else:
-                        _dict['href'] = f'{_dict["href"]}?project_id={wml_client.default_project_id}'
-
         del _dict['_initial_asset_id']
 
         return _dict
 
+    @property
+    def wml_client(self):
+        return self.__wml_client
+
+    @wml_client.setter
+    def wml_client(self, var):
+        self.__wml_client = var
+
+        if self.__wml_client:
+            self.href = self.__wml_client.service_instance._href_definitions.get_base_asset_href(self._initial_asset_id)
+        else:
+            self.href = f'/v2/assets/{self._initial_asset_id}'
+
+        if not self._wsd:
+            if self.__wml_client:
+                if self.__wml_client.default_space_id:
+                    self.href = f'{self.href}?space_id={self.__wml_client.default_space_id}'
+                else:
+                    self.href = f'{self.href}?project_id={self.__wml_client.default_project_id}'
+
 
 class ConnectionAssetLocation(BaseLocation):
     """
@@ -1123,6 +1146,7 @@ class WSDAssetLocation(BaseLocation):
         self._asset_id = None
         self._local_asset_path = None
         self._initial_asset_id = asset_id
+        self.__wml_client = None
 
         warning_msg = ("Depreciation Warning: Class WSDAssetLocation is no longer supported and will be removed."
                        "Use AssetLocation instead.")
@@ -1174,19 +1198,26 @@ class WSDAssetLocation(BaseLocation):
         location.href = href
         return location
 
-    def to_dict(self, wml_client=None) -> dict:
+    @property
+    def wml_client(self):
+        return self.__wml_client
+
+    @wml_client.setter
+    def wml_client(self, var):
+        self.__wml_client = var
+
+        if self.__wml_client:
+            self.href = self.__wml_client.service_instance._href_definitions.get_base_asset_href(self._initial_asset_id)
+        else:
+            self.href = f'/v2/assets/{self._initial_asset_id}'
+
+    def to_dict(self) -> dict:
         """Return a json dictionary representing this model."""
         _dict = vars(self).copy()
         del _dict['_asset_name']
         del _dict['_asset_id']
         del _dict['_local_asset_path']
-
-        if self.href is None:
-            if wml_client:
-                _dict['href'] = wml_client.service_instance._href_definitions.get_base_asset_href(self._initial_asset_id)
-            else:
-                _dict['href'] = f'/v2/assets/{self._initial_asset_id}'
-
+        del _dict[f"_{self.__class__.__name__}__wml_client"]
         del _dict['_initial_asset_id']
 
         return _dict
