@@ -172,6 +172,25 @@ class FlightService:
         data = pa.Table.from_batches(chunks)
         return data.to_pandas()
 
+    @staticmethod
+    def _cast_columns_to_float_64(data: 'pd.DataFrame') -> 'pd.DataFrame':
+        """Flight Service will cast decfloat types to strings, we need to cast them to correct types."""
+        for i, (col_name, col_type) in enumerate(zip(data.dtypes.index, data.dtypes)):
+
+            if col_type == 'object':
+                print(col_name)
+
+                try:
+                    data[col_name] = data[col_name].astype('float64')
+
+                except ValueError:  # ignore when column cannot be cast to other type than string
+                    pass
+
+                except Exception as e:
+                    pass
+
+        return data
+
     def _read_batch(self, batch_number: int, sequence_number: int,
                     endpoint: 'flight.FlightEndpoint', dfs: List['pd.DataFrame']) -> None:
         """This method should be used as a separate thread for downloading specific batch of data in parallel.
@@ -251,7 +270,7 @@ class FlightService:
                 # print(f"Joining batch reading thread {i}, sequence: {n}...")
                 thread.join()
 
-        dfs = pd.concat(dfs)
+        dfs = self._cast_columns_to_float_64(data=pd.concat(dfs))
 
         # Note: be sure that we do not cross upper data size limit
         estimated_data_size = sys.getsizeof(dfs)
