@@ -22,6 +22,8 @@ INSTANCE_ENDPOINT_HREF_PATTERN = u'{}/v3/wml_instance'
 INSTANCE_BY_ID_ENDPOINT_HREF_PATTERN = u'{}/v3/wml_instances/{}'
 TOKEN_ENDPOINT_HREF_PATTERN = u'{}/v3/identity/token'
 CPD_TOKEN_ENDPOINT_HREF_PATTERN = u'{}/icp4d-api/v1/authorize'
+CPD_BEDROCK_TOKEN_ENDPOINT_HREF_PATTERN = u'{}/idprovider/v1/auth/identitytoken'
+CPD_VALIDATION_TOKEN_ENDPOINT_HREF_PATTERN = u'{}/v1/preauth/validateAuth'
 EXPERIMENTS_HREF_PATTERN = u'{}/v4/experiments'
 EXPERIMENT_HREF_PATTERN = u'{}/v4/experiments/{}'
 EXPERIMENT_RUNS_HREF_PATTERN = u'{}/v3/experiments/{}/runs'
@@ -96,21 +98,30 @@ LIBRARIES=u'/libraries'
 RUNTIMES=u'/runtimes'
 SOFTWARE_SPEC=u'/software_specifications'
 DEPLOYMENTS = u'/deployments'
-MODEL_DEFINITION_ASSETS = u'{}/v2/assets'
-MODEL_DEFINITION_SEARCH_ASSETS = u'{}/v2/asset_types/wml_model_definition/search'
-WSD_SEARCH_ASSETS = u'{}/v2/asset_types/{}/search'
-DATA_ASSETS = u'{}/v2/assets'
-DATA_ASSET = u'{}/v2/assets/{}'
 ASSET = u'{}/v2/assets/{}'
 ASSETS = u'{}/v2/assets'
+ASSET_TYPE = u'{}/v2/asset_types'
+ASSET_FILES = u'{}/v2/asset_files/'
 ATTACHMENT = u'{}/v2/assets/{}/attachments/{}'
 ATTACHMENT_COMPLETE = u'{}/v2/assets/{}/attachments/{}/complete'
 ATTACHMENTS = u'{}/v2/assets/{}/attachments'
-SEARCH_ASSETS = u'{}/v2/asset_types/data_asset/search'
+SEARCH_ASSETS = u'{}/v2/asset_types/{}/search'
+SEARCH_MODEL_DEFINITIONS = u'{}/v2/asset_types/wml_model_definition/search'
+SEARCH_DATA_ASSETS = u'{}/v2/asset_types/data_asset/search'
 SEARCH_SHINY = u'{}/v2/asset_types/shiny_asset/search'
 SEARCH_SCRIPT = u'{}/v2/asset_types/script/search'
-ASSET_FILES = u'{}/v2/asset_files/'
-ASSET_TYPE = u'{}/v2/asset_types'
+GIT_BASED_PROJECT_ASSET = u'{}/userfs/v2/assets/{}'
+GIT_BASED_PROJECT_ASSETS = u'{}/userfs/v2/assets'
+GIT_BASED_PROJECT_ASSET_TYPE = u'{}/userfs/v2/asset_types'
+GIT_BASED_PROJECT_ASSET_FILES = u'{}/userfs/v2/asset_files/'
+GIT_BASED_PROJECT_ATTACHMENT = u'{}/userfs/v2/assets/{}/attachments/{}'
+GIT_BASED_PROJECT_ATTACHMENT_COMPLETE = u'{}/userfs/v2/assets/{}/attachments/{}/complete'
+GIT_BASED_PROJECT_ATTACHMENTS = u'{}/userfs/v2/assets/{}/attachments'
+GIT_BASED_PROJECT_SEARCH_ASSETS = u'{}/userfs/v2/asset_types/{}/search'
+GIT_BASED_PROJECT_SEARCH_MODEL_DEFINITIONS = u'{}/userfs/v2/asset_types/wml_model_definition/search'
+GIT_BASED_PROJECT_SEARCH_DATA_ASSETS = u'{}/userfs/v2/asset_types/data_asset/search'
+GIT_BASED_PROJECT_SEARCH_SHINY = u'{}/userfs/v2/asset_types/shiny_asset/search'
+GIT_BASED_PROJECT_SEARCH_SCRIPT = u'{}/userfs/v2/asset_types/script/search'
 DATA_SOURCE_TYPE = u'{}/v2/datasource_types'
 DATA_SOURCE_TYPE_BY_ID = u'{}/v2/datasource_types/{}'
 CONNECTION_ASSET = u'{}/v2/connections'
@@ -153,10 +164,12 @@ def is_uid(s):
 
 
 class HrefDefinitions:
-    def __init__(self, wml_credentials, cloud_platform_spaces=False, platform_url=None, cams_url=None, cp4d_platform_spaces=False):
+    def __init__(self, wml_credentials, cloud_platform_spaces=False, platform_url=None, cams_url=None,
+                 cp4d_platform_spaces=False, git_based_project=False):
         self._wml_credentials = wml_credentials
         self.cloud_platform_spaces = cloud_platform_spaces
         self.cp4d_platform_spaces = cp4d_platform_spaces
+        self.git_based_project = git_based_project
         self.platform_url = platform_url
         self.cams_url = cams_url
 
@@ -165,8 +178,13 @@ class HrefDefinitions:
         else:
             self.prepend = ''
 
-    def get_training_href(self, model_uid):
+    def _get_platform_url_if_exists(self):
+        return self.platform_url if self.platform_url else self._wml_credentials['url']
 
+    def _get_cams_url_if_exists(self):
+        return self.cams_url if self.cams_url else self._wml_credentials['url']
+
+    def get_training_href(self, model_uid):
         return TRAINING_MODEL_HREF_PATTERN.format(self._wml_credentials['url'] + self.prepend, model_uid)
 
     def get_trainings_href(self):
@@ -187,6 +205,12 @@ class HrefDefinitions:
     def get_cpd_token_endpoint_href(self):
         return CPD_TOKEN_ENDPOINT_HREF_PATTERN.format(self._wml_credentials['url'].replace(':31002', ':31843'))
 
+    def get_cpd_bedrock_token_endpoint_href(self):
+        return CPD_BEDROCK_TOKEN_ENDPOINT_HREF_PATTERN.format(self._wml_credentials['bedrock_url'])
+
+    def get_cpd_validation_token_endpoint_href(self):
+        return CPD_VALIDATION_TOKEN_ENDPOINT_HREF_PATTERN.format(self._wml_credentials['url'])
+
     def get_published_model_href(self, model_uid):
         return PUBLISHED_MODEL_HREF_PATTERN.format(self._wml_credentials['url'] + self.prepend, model_uid)
 
@@ -272,29 +296,16 @@ class HrefDefinitions:
         return SPACES_HREF_PATTERN.format(self._wml_credentials['url'])
 
     def get_platform_space_href(self, spaces_id):
-        # return SPACE_PLATFORM_HREF_PATTERN.format(self._wml_credentials['url'], spaces_id)
-        if self.platform_url is None:
-            return SPACE_PLATFORM_HREF_PATTERN.format(self._wml_credentials['url'], spaces_id)
-        else:
-            return SPACE_PLATFORM_HREF_PATTERN.format(self.platform_url, spaces_id)
+        return SPACE_PLATFORM_HREF_PATTERN.format(self._get_platform_url_if_exists(), spaces_id)
 
     def get_platform_spaces_href(self):
-        if self.platform_url is None:
-            return SPACES_PLATFORM_HREF_PATTERN.format(self._wml_credentials['url'])
-        else:
-            return SPACES_PLATFORM_HREF_PATTERN.format(self.platform_url)
+        return SPACES_PLATFORM_HREF_PATTERN.format(self._get_platform_url_if_exists())
 
     def get_platform_spaces_member_href(self, spaces_id, member_id):
-        if self.platform_url is None:
-            return SPACES_MEMBER_HREF_PATTERN.format(self._wml_credentials['url'], spaces_id, member_id)
-        else:
-            return SPACES_MEMBER_HREF_PATTERN.format(self.platform_url, spaces_id, member_id)
+        return SPACES_MEMBER_HREF_PATTERN.format(self._get_platform_url_if_exists(), spaces_id, member_id)
 
     def get_platform_spaces_members_href(self,spaces_id):
-        if self.platform_url is None:
-            return SPACES_MEMBERS_HREF_PATTERN.format(self._wml_credentials['url'], spaces_id)
-        else:
-            return SPACES_MEMBERS_HREF_PATTERN.format(self.platform_url, spaces_id)
+        return SPACES_MEMBERS_HREF_PATTERN.format(self._get_platform_url_if_exists(), spaces_id)
 
     def get_v4_instance_id_href(self):
         return V4_INSTANCE_ID_HREF_PATTERN.format(self._wml_credentials['url'],
@@ -310,10 +321,11 @@ class HrefDefinitions:
         return IAM_TOKEN_API.format(self._wml_credentials['apikey'])
 
     def get_iam_token_url(self):
-        if (self._wml_credentials['url'] in PROD_SVT_URL):
+        if self._wml_credentials['url'] in PROD_SVT_URL:
             return IAM_TOKEN_URL.format('https://iam.cloud.ibm.com')
         else:
             return IAM_TOKEN_URL.format('https://iam.test.cloud.ibm.com')
+
     def get_member_href(self, spaces_uid,member_id):
         return MEMBER_HREF_PATTERN.format(self._wml_credentials['url'], spaces_uid,member_id)
 
@@ -321,174 +333,109 @@ class HrefDefinitions:
         return MEMBERS_HREF_PATTERN.format(self._wml_credentials['url'],spaces_uid)
 
     def get_data_asset_href(self,asset_id):
-        # return DATA_ASSET.format(self._wml_credentials['url'],asset_id)
-        if self.cams_url is None:
-            return DATA_ASSET.format(self._wml_credentials['url'], asset_id)
-        else:
-            return DATA_ASSET.format(self.cams_url, asset_id)
+        return (ASSET if not self.git_based_project else GIT_BASED_PROJECT_ASSET)\
+            .format(self._get_cams_url_if_exists(), asset_id)
 
     def get_data_assets_href(self):
-        # return DATA_ASSETS.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return DATA_ASSETS.format(self._wml_credentials['url'])
-        else:
-            return DATA_ASSETS.format(self.cams_url)
+        return (ASSETS if not self.git_based_project else GIT_BASED_PROJECT_ASSETS)\
+            .format(self._get_cams_url_if_exists())
 
     def get_assets_href(self):
-        # return DATA_ASSETS.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return ASSETS.format(self._wml_credentials['url'])
-        else:
-            return ASSETS.format(self.cams_url)
+        return (ASSETS if not self.git_based_project else GIT_BASED_PROJECT_ASSETS)\
+            .format(self._get_cams_url_if_exists())
 
     def get_asset_href(self,asset_id):
-        # return ASSET.format(self._wml_credentials['url'],asset_id)
-        if self.cams_url is None:
-            return ASSET.format(self._wml_credentials['url'], asset_id)
-        else:
-            return ASSET.format(self.cams_url, asset_id)
+        return (ASSET if not self.git_based_project else GIT_BASED_PROJECT_ASSET)\
+            .format(self._get_cams_url_if_exists(), asset_id)
+
+    def get_base_asset_href(self,asset_id):
+        return (ASSET if not self.git_based_project else GIT_BASED_PROJECT_ASSET).format('', asset_id)
+
+    def get_base_assets_href(self):
+        return (ASSETS if not self.git_based_project else GIT_BASED_PROJECT_ASSETS).format('')
+
+    def get_base_asset_with_type_href(self,asset_type, asset_id):
+        return (ASSET if not self.git_based_project else GIT_BASED_PROJECT_ASSET).format('', asset_type) + '/' + asset_id
 
     def get_attachment_href(self,asset_id,attachment_id):
-        # return ATTACHMENT.format(self._wml_credentials['url'],asset_id,attachment_id)
-        if self.cams_url is None:
-            return ATTACHMENT.format(self._wml_credentials['url'], asset_id, attachment_id)
-        else:
-            return ATTACHMENT.format(self.cams_url, asset_id, attachment_id)
+        return (ATTACHMENT if not self.git_based_project else GIT_BASED_PROJECT_ATTACHMENT)\
+            .format(self._get_cams_url_if_exists(), asset_id, attachment_id)
 
     def get_attachments_href(self, asset_id):
-        # return ATTACHMENT.format(self._wml_credentials['url'],asset_id,attachment_id)
-        if self.cams_url is None:
-            return ATTACHMENTS.format(self._wml_credentials['url'], asset_id )
-        else:
-            return ATTACHMENTS.format(self.cams_url, asset_id)
+        return (ATTACHMENTS if not self.git_based_project else GIT_BASED_PROJECT_ATTACHMENTS)\
+            .format(self._get_cams_url_if_exists(), asset_id)
 
     def get_attachment_complete_href(self,asset_id,attachment_id):
-        # return ATTACHMENT.format(self._wml_credentials['url'],asset_id,attachment_id)
-        if self.cams_url is None:
-            return ATTACHMENT_COMPLETE.format(self._wml_credentials['url'], asset_id, attachment_id)
-        else:
-            return ATTACHMENT_COMPLETE.format(self.cams_url, asset_id, attachment_id)
+        return (ATTACHMENT_COMPLETE if not self.git_based_project else GIT_BASED_PROJECT_ATTACHMENT_COMPLETE)\
+            .format(self._get_cams_url_if_exists(), asset_id, attachment_id)
 
     def get_search_asset_href(self):
-        # return SEARCH_ASSETS.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return SEARCH_ASSETS.format(self._wml_credentials['url'])
-        else:
-            return SEARCH_ASSETS.format(self.cams_url)
+        return (SEARCH_DATA_ASSETS if not self.git_based_project else GIT_BASED_PROJECT_SEARCH_DATA_ASSETS)\
+            .format(self._get_cams_url_if_exists())
 
     def get_search_shiny_href(self):
-        # return SEARCH_SHINY.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return SEARCH_SHINY.format(self._wml_credentials['url'])
-        else:
-            return SEARCH_SHINY.format(self.cams_url)
+        return (SEARCH_SHINY if not self.git_based_project else GIT_BASED_PROJECT_SEARCH_SHINY)\
+            .format(self._get_cams_url_if_exists())
 
     def get_search_script_href(self):
-        # return SEARCH_SCRIPT.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return SEARCH_SCRIPT.format(self._wml_credentials['url'])
-        else:
-            return SEARCH_SCRIPT.format(self.cams_url)
+        return (SEARCH_SCRIPT if not self.git_based_project else GIT_BASED_PROJECT_SEARCH_SCRIPT)\
+            .format(self._get_cams_url_if_exists())
 
     def get_model_definition_assets_href(self):
-        # return MODEL_DEFINITION_ASSETS.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return MODEL_DEFINITION_ASSETS.format(self._wml_credentials['url'])
-        else:
-            return MODEL_DEFINITION_ASSETS.format(self.cams_url)
+        return (ASSETS if not self.git_based_project else GIT_BASED_PROJECT_ASSETS)\
+            .format(self._get_cams_url_if_exists())
 
     def get_model_definition_search_asset_href(self):
-        # return MODEL_DEFINITION_SEARCH_ASSETS.format(self._wml_credentials['url'])
-        if self.cams_url is None:
-            return MODEL_DEFINITION_SEARCH_ASSETS.format(self._wml_credentials['url'])
-        else:
-            return MODEL_DEFINITION_SEARCH_ASSETS.format(self.cams_url)
+        return (SEARCH_MODEL_DEFINITIONS if not self.git_based_project else GIT_BASED_PROJECT_SEARCH_MODEL_DEFINITIONS)\
+            .format(self._get_cams_url_if_exists())
 
     def get_wsd_model_href(self):
-        return MODEL_DEFINITION_ASSETS.format(self._wml_credentials['url'])
+        return (ASSETS if not self.git_based_project else GIT_BASED_PROJECT_ASSETS).format(self._wml_credentials['url'])
 
     def get_wsd_model_attachment_href(self):
-        return ASSET_FILES.format(self._wml_credentials['url'])
+        return (ASSET_FILES if not self.git_based_project else GIT_BASED_PROJECT_ASSET_FILES)\
+            .format(self._wml_credentials['url'])
 
     def get_wsd_asset_search_href(self, asset_type):
-        return WSD_SEARCH_ASSETS.format(self._wml_credentials['url'], asset_type)
+        return (SEARCH_ASSETS if not self.git_based_project else GIT_BASED_PROJECT_SEARCH_ASSETS)\
+            .format(self._wml_credentials['url'], asset_type)
 
     def get_wsd_asset_type_href(self):
-        return ASSET_TYPE.format(self._wml_credentials['url'])
+        return (ASSET_TYPE if not self.git_based_project else GIT_BASED_PROJECT_ASSET_TYPE)\
+            .format(self._wml_credentials['url'])
 
     def get_wsd_base_href(self):
         return self._wml_credentials['url']
 
     def get_connections_href(self):
-        # return CONNECTION_ASSET.format(self._wml_credentials['url'])
-        if self.platform_url is None:
-            return CONNECTION_ASSET.format(self._wml_credentials['url'])
-        else:
-            return CONNECTION_ASSET.format(self.platform_url)
+        return CONNECTION_ASSET.format(self._get_platform_url_if_exists())
 
     def get_connection_by_id_href(self, connection_id):
-        # return CONNECTION_BY_ID.format(self._wml_credentials['url'], connection_id)
-        if self.platform_url is None:
-            return CONNECTION_BY_ID.format(self._wml_credentials['url'], connection_id)
-        else:
-            return CONNECTION_BY_ID.format(self.platform_url, connection_id)
+        return CONNECTION_BY_ID.format(self._get_platform_url_if_exists(), connection_id)
 
     def get_connection_data_types_href(self):
-        # return DATA_SOURCE_TYPE.format(self._wml_credentials['url'])
-        if self.platform_url is None:
-            return DATA_SOURCE_TYPE.format(self._wml_credentials['url'])
-        else:
-            return DATA_SOURCE_TYPE.format(self.platform_url)
+        return DATA_SOURCE_TYPE.format(self._get_platform_url_if_exists())
 
     def get_sw_spec_href(self, sw_spec_id):
-        # return SOFTWARE_SPECIFICATION.format(self._wml_credentials['url'], sw_spec_id)
-        if self.platform_url is None:
-            return SOFTWARE_SPECIFICATION.format(self._wml_credentials['url'], sw_spec_id)
-        else:
-            return SOFTWARE_SPECIFICATION.format(self.platform_url, sw_spec_id)
+        return SOFTWARE_SPECIFICATION.format(self._get_platform_url_if_exists(), sw_spec_id)
 
     def get_sw_specs_href(self):
-        # return SOFTWARE_SPECIFICATIONS.format(self._wml_credentials['url'])
-        if self.platform_url is None:
-            return SOFTWARE_SPECIFICATIONS.format(self._wml_credentials['url'])
-        else:
-            return SOFTWARE_SPECIFICATIONS.format(self.platform_url)
+        return SOFTWARE_SPECIFICATIONS.format(self._get_platform_url_if_exists())
 
     def get_hw_spec_href(self, hw_spec_id):
-        # return HARDWARE_SPECIFICATION.format(self._wml_credentials['url'], hw_spec_id)
-        if self.platform_url is None:
-            return HARDWARE_SPECIFICATION.format(self._wml_credentials['url'], hw_spec_id)
-        else:
-            return HARDWARE_SPECIFICATION.format(self.platform_url, hw_spec_id)
+        return HARDWARE_SPECIFICATION.format(self._get_platform_url_if_exists(), hw_spec_id)
 
     def get_hw_specs_href(self):
-        # return HARDWARE_SPECIFICATIONS.format(self._wml_credentials['url'])
-        if self.platform_url is None:
-            return HARDWARE_SPECIFICATIONS.format(self._wml_credentials['url'])
-        else:
-            return HARDWARE_SPECIFICATIONS.format(self.platform_url)
+        return HARDWARE_SPECIFICATIONS.format(self._get_platform_url_if_exists())
 
     def get_pkg_extn_href(self, pkg_extn_id):
-        # return PACKAGE_EXTENSION.format(self._wml_credentials['url'], pkg_extn_id)
-        if self.platform_url is None:
-            return PACKAGE_EXTENSION.format(self._wml_credentials['url'], pkg_extn_id)
-        else:
-            return PACKAGE_EXTENSION.format(self.platform_url, pkg_extn_id)
+        return PACKAGE_EXTENSION.format(self._get_platform_url_if_exists(), pkg_extn_id)
 
     def get_pkg_extns_href(self):
-        # return PACKAGE_EXTENSIONS.format(self._wml_credentials['url'])
-        if self.platform_url is None:
-            return PACKAGE_EXTENSIONS.format(self._wml_credentials['url'])
-        else:
-            return PACKAGE_EXTENSIONS.format(self.platform_url)
+        return PACKAGE_EXTENSIONS.format(self._get_platform_url_if_exists())
 
     def get_project_href(self, project_id):
-        # return PROJECT.format(self._wml_credentials['url'], project_id)
-
-        if self.platform_url is None:
-            return PROJECT.format(self._wml_credentials['url'], project_id)
-        else:
-            return PROJECT.format(self.platform_url, project_id)
+        return PROJECT.format(self._get_platform_url_if_exists(), project_id)
 
     def v4ga_cloud_migration_href(self):
         return V4GA_CLOUD_MIGRATION.format(self._wml_credentials['url'])
@@ -496,48 +443,20 @@ class HrefDefinitions:
     def v4ga_cloud_migration_id_href(self, migration_id):
         return V4GA_CLOUD_MIGRATION_ID.format(self._wml_credentials['url'], migration_id)
 
-    def remote_training_system_href(self, remote_training_systems_id):
-        if self.platform_url is None:
-            return REMOTE_TRAINING_SYSTEM_ID.format(self._wml_credentials['url'], remote_training_systems_id)
-        else:
-            return REMOTE_TRAINING_SYSTEM_ID.format(self.platform_url, remote_training_systems_id)
-
-    def remote_training_systems_href(self):
-        # return PACKAGE_EXTENSIONS.format(self._wml_credentials['url'])
-        if self.platform_url is None:
-            return REMOTE_TRAINING_SYSTEM.format(self._wml_credentials['url'])
-        else:
-            return REMOTE_TRAINING_SYSTEM.format(self.platform_url)
-
     def exports_href(self):
-        if self.platform_url is None:
-            return EXPORTS.format(self._wml_credentials['url'])
-        else:
-            return EXPORTS.format(self.platform_url)
+        return EXPORTS.format(self._get_platform_url_if_exists())
 
     def export_href(self, export_id):
-        if self.platform_url is None:
-            return EXPORT_ID.format(self._wml_credentials['url'], export_id)
-        else:
-            return EXPORT_ID.format(self.platform_url, export_id)
+        return EXPORT_ID.format(self._get_platform_url_if_exists(), export_id)
 
     def export_content_href(self, export_id):
-        if self.platform_url is None:
-            return EXPORT_ID_CONTENT.format(self._wml_credentials['url'], export_id)
-        else:
-            return EXPORT_ID_CONTENT.format(self.platform_url, export_id)
+        return EXPORT_ID_CONTENT.format(self._get_platform_url_if_exists(), export_id)
 
     def imports_href(self):
-        if self.platform_url is None:
-            return IMPORTS.format(self._wml_credentials['url'])
-        else:
-            return IMPORTS.format(self.platform_url)
+        return IMPORTS.format(self._get_platform_url_if_exists())
 
     def import_href(self, export_id):
-        if self.platform_url is None:
-            return IMPORT_ID.format(self._wml_credentials['url'], export_id)
-        else:
-            return IMPORT_ID.format(self.platform_url, export_id)
+        return IMPORT_ID.format(self._get_platform_url_if_exists(), export_id)
 
     def remote_training_systems_href(self):
         return REMOTE_TRAINING_SYSTEM.format(self._wml_credentials['url'] + self.prepend)
@@ -549,10 +468,10 @@ class HrefDefinitions:
         return VOLUMES.format(self._wml_credentials['url'])
 
     def volume_href(self,volume_id):
-        return VOLUME_ID.format(self._wml_credentials['url'],volume_id)
+        return VOLUME_ID.format(self._wml_credentials['url'], volume_id)
 
     def volume_service_href(self,volume_name):
-        return VOLUME_SERVICE.format(self._wml_credentials['url'],volume_name)
+        return VOLUME_SERVICE.format(self._wml_credentials['url'], volume_name)
 
     def volume_upload_href(self, volume_name):
         return VOLUME_SERVICE_FILE_UPLOAD.format(self._wml_credentials['url'], volume_name)
