@@ -59,10 +59,10 @@ class PkgExtn(WMLResource):
         PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.get(self._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get hw spec details', response))
@@ -119,7 +119,7 @@ class PkgExtn(WMLResource):
         f = {'file': open(file_path, 'rb')}
         #Step1  : Create an asset
         print("Creating package extensions")
-        href = self._href_definitions.get_pkg_extns_href()
+        href = self._client.service_instance._href_definitions.get_pkg_extns_href()
 
         if not self._ICP:
             creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json)
@@ -148,13 +148,13 @@ class PkgExtn(WMLResource):
                 # Step3: Mark the upload complete
                 if not self._ICP:
                     complete_response = requests.post(
-                        self._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
+                        self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
                         headers=self._client._get_headers(),
                         params=self._client._params()
                     )
                 else:
                     complete_response = requests.post(
-                        self._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
+                        self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_asset_id) + "/upload_complete",
                         headers=self._client._get_headers(),
                         params=self._client._params(),
                         verify=False
@@ -188,7 +188,7 @@ class PkgExtn(WMLResource):
 
         """
 
-        href = self._href_definitions.get_pkg_extns_href()
+        href = self._client.service_instance._href_definitions.get_pkg_extns_href()
 
         if not self._ICP:
             response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
@@ -297,12 +297,12 @@ class PkgExtn(WMLResource):
         parameters = self._client._params()
         parameters.update(name=pkg_extn_name)
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_pkg_extns_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extns_href(),
                                     params=parameters,
                                     headers=self._client._get_headers())
         else:
 
-            response = requests.get(self._href_definitions.get_pkg_extns_href(),
+            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extns_href(),
                                     params=parameters,
                                     headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
@@ -398,10 +398,10 @@ class PkgExtn(WMLResource):
         PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
@@ -413,10 +413,10 @@ class PkgExtn(WMLResource):
         PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                        headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
                                        headers=self._client._get_headers(), verify=False)
 
     def _get_required_element_from_response(self, response_data):
@@ -437,7 +437,7 @@ class PkgExtn(WMLResource):
             elif self._client.default_project_id is not None:
                 if self._client.WSD:
 
-                    href = "/v2/assets/" + response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                    href = self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
 
                     new_el = {'metadata': {'project_id': response_data['metadata']['project_id'],
                                            'name': response_data['metadata']['name'],
@@ -496,7 +496,7 @@ class PkgExtn(WMLResource):
 
         if self._WSD:
             import urllib
-            pkg_extn_response = requests.get(self._href_definitions.get_pkg_extn_href(pkg_extn_id),
+            pkg_extn_response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
                                           params=self._client._params(),
                                           headers=self._client._get_headers())
 
@@ -519,11 +519,11 @@ class PkgExtn(WMLResource):
                 raise WMLClientError(u'Saving asset with artifact_url: \'{}\' failed.'.format(filename), e)
         else:
             if not self._ICP:
-                pkg_extn_response = requests.get(self._href_definitions.get_pkg_extn_href(pkg_extn_id),
+                pkg_extn_response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
                                           params=self._client._params(),
                                           headers=self._client._get_headers())
             else:
-                pkg_extn_response = requests.get(self._href_definitions.get_pkg_extn_href(pkg_extn_id),
+                pkg_extn_response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_id),
                                                  params=self._client._params(),
                                                  headers=self._client._get_headers(),
                                                  verify=False)
