@@ -61,10 +61,10 @@ class Shiny(WMLResource):
 
 
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.get(self._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(shiny_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             response = self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
@@ -208,7 +208,7 @@ class Shiny(WMLResource):
             creation_response = ""
             if not self._ICP:
                 creation_response = requests.post(
-                        self._href_definitions.get_data_assets_href(),
+                        self._client.service_instance._href_definitions.get_data_assets_href(),
                         headers=self._client._get_headers(),
                         params = self._client._params(),
                         json=asset_meta
@@ -216,7 +216,7 @@ class Shiny(WMLResource):
             else:
                 if self._client.ICP_PLATFORM_SPACES:
                     creation_response = requests.post(
-                        self._href_definitions.get_data_assets_href(),
+                        self._client.service_instance._href_definitions.get_data_assets_href(),
                         headers=self._client._get_headers(),
                         params=self._client._params(),
                         json=asset_meta,
@@ -225,7 +225,7 @@ class Shiny(WMLResource):
                 else:
                     # Until global asset for shiny is created
                     asset_type_response = requests.post(
-                        self._wml_credentials['url'] + "/v2/asset_types?",
+                        self._client.service_instance._href_definitions.get_wsd_asset_type_href() + '?',
                         headers=self._client._get_headers(),
                         json=base_shiny_asset,
                         params=self._client._params(),
@@ -233,7 +233,7 @@ class Shiny(WMLResource):
                     )
                     if asset_type_response.status_code == 201 or asset_type_response.status_code == 409:
                         creation_response = requests.post(
-                            self._href_definitions.get_data_assets_href(),
+                            self._client.service_instance._href_definitions.get_data_assets_href(),
                             headers=self._client._get_headers(),
                             json=asset_meta,
                             params=self._client._params(),
@@ -251,14 +251,14 @@ class Shiny(WMLResource):
 
                 if not self._ICP:
                     attachment_response = requests.post(
-                        self._href_definitions.get_attachments_href(asset_id),
+                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
                         headers=self._client._get_headers(),
                         params=self._client._params(),
                         json=attachment_meta
                     )
                 else:
                     attachment_response = requests.post(
-                        self._wml_credentials['url']+"/v2/assets/"+asset_id+"/attachments",
+                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
                         headers=self._client._get_headers(),
                         json=attachment_meta,
                         params=self._client._params(),
@@ -287,15 +287,15 @@ class Shiny(WMLResource):
                         # Step4: Complete attachment
                         if not self._ICP:
                             complete_response = requests.post(
-                                # self._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
-                                self._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
+                                # self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
+                                self._client.service_instance._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
                                 headers=self._client._get_headers(),
                                 params = self._client._params()
 
                             )
                         else:
                             complete_response = requests.post(
-                                self._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
+                                self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
                                 headers=self._client._get_headers(),
                                 params=self._client._params(),
                                 verify=False
@@ -338,7 +338,7 @@ class Shiny(WMLResource):
         """
 
         Shiny._validate_type(limit, u'limit', int, False)
-        href = self._href_definitions.get_search_shiny_href()
+        href = self._client.service_instance._href_definitions.get_search_shiny_href()
 
         data = {
                 "query": "*:*"
@@ -397,18 +397,18 @@ class Shiny(WMLResource):
 
         import urllib
         if not self._ICP:
-            asset_response = requests.get(self._href_definitions.get_data_asset_href(asset_uid),
+            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
                                           params=params,
                                           headers=self._client._get_headers())
         else:
-            asset_response = requests.get(self._href_definitions.get_data_asset_href(asset_uid),
+            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
                                           params=params,
                                           headers=self._client._get_headers(), verify=False)
         asset_details = self._handle_response(200, u'get assets', asset_response)
 
         if self._WSD:
             attachment_url = asset_details['attachments'][0]['object_key']
-            artifact_content_url = self._href_definitions.get_wsd_model_attachment_href() + \
+            artifact_content_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                    urllib.parse.quote('shiny_asset/' + attachment_url, safe='')
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
@@ -427,10 +427,10 @@ class Shiny(WMLResource):
         else:
             attachment_id = asset_details["attachments"][0]["id"]
             if not self._ICP:
-                response = requests.get(self._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
                                         headers=self._client._get_headers())
             else:
-                response = requests.get(self._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
                                           headers=self._client._get_headers(), verify=False)
             if response.status_code == 200:
                 attachment_signed_url = response.json()["url"]
@@ -576,7 +576,7 @@ class Shiny(WMLResource):
         updated_details = None
         details = None
 
-        url = self._href_definitions.get_asset_href(shiny_uid)
+        url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid)
 
         # STEPS
         # STEP 1. Get existing metadata
@@ -637,7 +637,7 @@ class Shiny(WMLResource):
                                                                                          with_validation=True,
                                                                                          asset_meta_patch=True)
             if meta_patch_payload:
-                meta_patch_url = self._href_definitions.get_asset_href(shiny_uid)
+                meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid)
 
                 if not self._ICP:
                     response_patch = requests.patch(meta_patch_url,
@@ -668,7 +668,7 @@ class Shiny(WMLResource):
             self._update_msg(updated_details)
 
         # Have to fetch again to reflect updated asset and attachment ids
-        url = self._href_definitions.get_asset_href(shiny_uid)
+        url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid)
 
         if not self._ICP:
             response = requests.get(
@@ -744,10 +744,10 @@ class Shiny(WMLResource):
                 u'Cannot delete shiny asset that has existing deployments. Please delete all associated deployments and try again')
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
@@ -822,7 +822,7 @@ class Shiny(WMLResource):
         shiny_uid = str_type_conv(shiny_uid)
         Shiny._validate_type(shiny_uid, u'shiny_uid', STR_TYPE, True)
 
-        url = self._href_definitions.get_asset_href(shiny_uid) + "/revisions"
+        url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid) + "/revisions"
         # /v2/assets/{asset_id}/revisions returns 'results' object
         shiny_resources = self._get_with_or_without_limit(url,
                                                            limit,
@@ -868,7 +868,7 @@ class Shiny(WMLResource):
         if rev_uid is None:
             rev_uid = 'latest'
 
-        url = self._href_definitions.get_asset_href(shiny_uid)
+        url = self._client.service_instance._href_definitions.get_asset_href(shiny_uid)
         # return self._get_required_element_from_response(self._get_with_or_without_limit(url,
         #                                        limit=None,
         #                                        op_name="asset_revision",
@@ -898,10 +898,10 @@ class Shiny(WMLResource):
         Shiny._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                        headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                        headers=self._client._get_headers(), verify=False)
 
 
@@ -938,10 +938,10 @@ class Shiny(WMLResource):
     #     Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
     #
     #     if not self._ICP:
-    #         response = requests.get(self._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+    #         response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
     #                                 headers=self._client._get_headers())
     #     else:
-    #         response = requests.get(self._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+    #         response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
     #                                 headers=self._client._get_headers(), verify=False)
     #     if response.status_code == 200:
     #         return response.json()["href"]
@@ -983,7 +983,7 @@ class Shiny(WMLResource):
             elif self._client.default_project_id is not None:
                 if self._client.WSD:
 
-                    href = "/v2/assets/" + response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                    href = self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
 
                     metadata = {'project_id': response_data['metadata']['project_id'],
                                 'guid': response_data['metadata']['asset_id'],
