@@ -1,5 +1,5 @@
 import unittest
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 from ibm_watson_machine_learning.tests.CP4D_35.preparation_and_cleaning import *
 
@@ -9,7 +9,7 @@ class TestWMLClientWithKeras(unittest.TestCase):
     model_uid = None
     scoring_url = None
     scoring_uid = None
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
 
     @classmethod
     def setUpClass(self):
