@@ -12,7 +12,7 @@ from ibm_watson_machine_learning.deployment import Batch
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.preprocessing.data_join_pipeline import OBMPipelineGraphBuilder
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, DSLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, AssetLocation
 
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 
