@@ -11,7 +11,7 @@ from ibm_watson_machine_learning import APIClient
 from ibm_watson_machine_learning.experiment import AutoAI
 from ibm_watson_machine_learning.deployment import WebService
 
-from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, DSLocation
+from ibm_watson_machine_learning.helpers.connections import S3Connection, S3Location, DataConnection, AssetLocation
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, bucket_name_gen
 from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup
@@ -134,7 +134,7 @@ class TestAutoAIRemote(unittest.TestCase):
             asset_id = asset_details['metadata']['guid']
 
             TestAutoAIRemote.data_connection = DataConnection(
-                                location=DSLocation(asset_id=asset_id))
+                                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else: #for cloud and COS
@@ -223,7 +223,7 @@ class TestAutoAIRemote(unittest.TestCase):
             asset_id = asset_details['metadata']['guid']
 
             TestAutoAIRemote.data_connection = DataConnection(
-                                location=DSLocation(asset_id=asset_id))
+                                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else: #for cloud and COS
@@ -308,7 +308,7 @@ class TestAutoAIRemote(unittest.TestCase):
             asset_id = asset_details['metadata']['guid']
 
             TestAutoAIRemote.data_connection = DataConnection(
-                location=DSLocation(asset_id=asset_id))
+                location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
         else:  # for cloud and COS
