@@ -85,14 +85,6 @@ class AbstractTestAutoAIRemote(abc.ABC):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         cls.cos_credentials = get_cos_credentials()
