@@ -102,14 +102,6 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials)
 
         if not cls.wml_client.ICP:
