@@ -66,8 +66,6 @@ class TestAutoAIRemote(unittest.TestCase):
 
     data_location = './autoai/data/xlsx/CarPrice_Assignment.xlsx'
 
-    prediction_column = 'price'
-    scoring_method = Metrics.ROOT_MEAN_SQUARED_ERROR
 
     batch_payload_location = './autoai/data/batch_payload/car_price_payload.csv'
 
@@ -82,6 +80,17 @@ class TestAutoAIRemote(unittest.TestCase):
 
     space_name = 'autoai_tests_sdk_space'
 
+    ## pipeline optimizer parameters
+
+    prediction_column = 'price'
+    scoring_method = Metrics.ROOT_MEAN_SQUARED_ERROR
+
+    max_number_of_estimators = 2
+    text_processing = False
+    drop_duplicates = False
+    daub_give_priority_to_runtime = 1
+    train_sample_rows_test_size=0.8
+
     OPTIMIZER_NAME = 'CarPrice wml_autoai regression test'
     DEPLOYMENT_NAME = "CarPrice AutoAI Deployment tests"
 
@@ -99,14 +108,6 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -120,6 +121,16 @@ class TestAutoAIRemote(unittest.TestCase):
 
         cls.project_id = cls.wml_credentials.get('project_id')
 
+    def _check_optimizer_parameters(self, parameters):
+        # check_pipeline_parameters:
+        self.assertIsNotNone(parameters.get('name'))
+
+        self.assertEqual(parameters.get('prediction_column'), self.prediction_column)
+        self.assertEqual(parameters.get('text_processing'), self.text_processing)
+        self.assertEqual(parameters.get('drop_duplicates'), self.drop_duplicates)
+        self.assertEqual(parameters.get('daub_give_priority_to_runtime'), self.daub_give_priority_to_runtime)
+        self.assertEqual(parameters.get('train_sample_rows_test_size'), self.train_sample_rows_test_size)
+
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
                       get_space_id(self.wml_client, self.space_name,
@@ -195,7 +206,12 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.prediction_column,
             # scoring=self.scoring_method,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L,
-            autoai_pod_version=self.pod_version
+            autoai_pod_version=self.pod_version,
+            max_number_of_estimators=self.max_number_of_estimators,
+            text_processing=self.text_processing,
+            drop_duplicates=self.drop_duplicates,
+            daub_give_priority_to_runtime=self.daub_give_priority_to_runtime,
+            train_sample_rows_test_size=self.train_sample_rows_test_size
         )
 
         self.assertIsInstance(self.remote_auto_pipelines, RemoteAutoPipelines,
@@ -204,7 +220,7 @@ class TestAutoAIRemote(unittest.TestCase):
     def test_04_get_configuration_parameters_of_remote_auto_pipeline(self):
         parameters = self.remote_auto_pipelines.get_params()
         print(parameters)
-        self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
+        self._check_optimizer_parameters(parameters)
 
     # def test_05_fit_run_training_of_auto_ai_in_wml(self):
     #     failure_count = 0
@@ -319,15 +335,21 @@ class TestAutoAIRemote(unittest.TestCase):
         print(pipelines_details)
         self.assertGreater(len(pipelines_details), 0)
 
-    def test_14_get_pipeline_params_specific_pipeline_parameters(self):
+    def test_14a_get_pipeline_params_specific_pipeline_parameters(self):
         pipeline_params = self.remote_auto_pipelines.get_pipeline_details(pipeline_name='Pipeline_1')
         print(pipeline_params)
         self.assertIn(f"holdout_{self.scoring_method}", str(pipeline_params))
 
-    def test_15_get_pipeline_params_best_pipeline_parameters(self):
+    def test_14b_get_pipeline_params_best_pipeline_parameters(self):
         best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
         self.assertIn(f"holdout_{self.scoring_method}", str(best_pipeline_params))
 
+    def test_15_check_params_of_realoaded_pipeline_optimizer(self):
+        historical_optimizer = self.experiment.runs.get_optimizer(self.run_id)
+        hist_opt_params = historical_optimizer.get_params()
+        print(hist_opt_params)
+        self._check_optimizer_parameters(hist_opt_params)
+
     def test_16_get_pipeline_load_specified_pipeline(self):
         TestAutoAIRemote.lale_pipeline = self.remote_auto_pipelines.get_pipeline(
             pipeline_name='Pipeline_1')
