@@ -186,10 +186,15 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsNotNone(obj=TestAutoAIRemote.data_connection)
 
     def test_02a_read_saved_remote_data_before_fit(self):
-        TestAutoAIRemote.data = self.data_connection.read(csv_separator=self.custom_separator)
-        print("Data sample:")
-        print(self.data.head())
-        self.assertGreater(len(self.data), 0)
+
+        if self.wml_client.ICP:
+            with self.assertRaises(NotImplementedError, msg="Should fail with adequate error"):
+                data = self.data_connection.read()
+        else:
+            TestAutoAIRemote.data = self.data_connection.read(csv_separator=self.custom_separator)
+            print("Data sample:")
+            print(TestAutoAIRemote.data.head())
+            self.assertGreater(len(TestAutoAIRemote.data), 0)
 
     #################################
     #       REMOTE OPTIMIZER        #
