@@ -98,14 +98,7 @@ class TestOBMOnly(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
+
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             if 'endpoint_url' in cls.cos_credentials:
