@@ -115,14 +115,7 @@ class TestOBMAndKB(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
+
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
