@@ -107,14 +107,7 @@ class TestOBMAndKB(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
-        try:
-            del cls.wml_credentials['bedrock_url']
-        except:
-            pass
-        try:
-            del cls.wml_credentials['password']
-        except:
-            pass
+
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
@@ -703,7 +696,7 @@ class TestOBMAndKB(unittest.TestCase):
                                         secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
                 location=S3Location(bucket=self.bucket_name,
                                     path="prediction_results.csv")
-            ),
+            )
 
         scoring_params = self.service.run_job(
             payload=payload_reference,
@@ -841,7 +834,7 @@ class TestOBMAndKB(unittest.TestCase):
                                         secret_access_key=self.cos_credentials['cos_hmac_keys']['secret_access_key']),
                 location=S3Location(bucket=self.bucket_name,
                                     path="prediction_results.csv")
-            ),
+            )
 
         scoring_params = self.service.run_job(
             payload=payload_reference,
