@@ -2,6 +2,9 @@ import unittest
 import os
 import logging
 from preparation_and_cleaning import *
+from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, get_space_id
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup
+from ibm_watson_machine_learning import APIClient
 
 
 class TestWMLClientWithKeras(unittest.TestCase):
@@ -9,34 +12,41 @@ class TestWMLClientWithKeras(unittest.TestCase):
     model_uid = None
     scoring_url = None
     x_test = None
+    space_name = 'tests_sdk_space'
+    space_id = None
+    model_path = os.path.join('.', 'svt', 'artifacts', 'keras_model.tgz')
     logger = logging.getLogger(__name__)
 
     @classmethod
-    def setUpClass(self):
-        TestWMLClientWithKeras.logger.info("Service Instance: setting up credentials")
+    def setUpClass(cls) -> None:
+        """
+        Load WML credentials from config.ini file based on ENV variable.
+        """
 
-        self.wml_credentials = get_wml_credentials()
-        self.client = get_client()
-        self.model_path = os.path.join(os.getcwd(), 'artifacts', 'keras_model.tgz')
+        cls.wml_credentials = get_wml_credentials()
 
-    def test_00_check_client_version(self):
-        TestWMLClientWithKeras.logger.info("Check client version...")
+        cls.wml_client = APIClient(wml_credentials=cls.wml_credentials)
 
-        self.logger.info("Getting version ...")
-        version = self.client.version
-        TestWMLClientWithKeras.logger.debug(version)
-        self.assertTrue(len(version) > 0)
+        if not cls.wml_client.ICP:
+            cls.cos_credentials = get_cos_credentials()
+            cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
+            cls.cos_resource_instance_id = cls.cos_credentials.get('resource_instance_id')
 
-    def test_01_service_instance_details(self):
-        TestWMLClientWithKeras.logger.info("Check client ...")
-        self.assertTrue(type(self.client).__name__ == 'APIClient')
+        cls.wml_client = APIClient(wml_credentials=cls.wml_credentials)
+        cls.project_id = cls.wml_credentials.get('project_id')
 
-        self.logger.info("Getting instance details ...")
-        details = self.client.service_instance.get_details()
-        TestWMLClientWithKeras.logger.debug(details)
+    def test_00a_space_cleanup(self):
+        space_cleanup(self.wml_client,
+                      get_space_id(self.wml_client, self.space_name,
+                                   cos_resource_instance_id=self.cos_resource_instance_id),
+                      days_old=7)
+        TestWMLClientWithKeras.space_id = get_space_id(self.wml_client, self.space_name,
+                                                       cos_resource_instance_id=self.cos_resource_instance_id)
 
-        self.assertTrue("published_models" in str(details))
-        self.assertEqual(type(details), dict)
+        # if self.wml_client.ICP:
+        #     self.wml_client.set.default_project(self.project_id)
+        # else:
+        self.wml_client.set.default_space(self.space_id)
 
     def test_02_publish_model(self):
         TestWMLClientWithKeras.logger.info("Creating keras model ...")
@@ -72,16 +82,19 @@ class TestWMLClientWithKeras(unittest.TestCase):
 
         self.logger.info("Publishing keras model ...")
 
-        self.client.repository.ModelMetaNames.show()
+        self.wml_client.repository.ModelMetaNames.show()
 
-        model_props = {self.client.repository.ModelMetaNames.NAME: "KerasModel-gzip",
-            self.client.repository.ModelMetaNames.TYPE: "keras_2.2.5",
-            self.client.repository.ModelMetaNames.RUNTIME_UID: "tensorflow_1.15-py3.6"
+        self.wml_client.software_specifications.list()
+        sw_spec_id = self.wml_client.software_specifications.get_id_by_name("default_py3.7")
+
+        model_props = {self.wml_client.repository.ModelMetaNames.NAME: "KerasModel-gzip",
+            self.wml_client.repository.ModelMetaNames.TYPE: "tensorflow_2.1",
+            self.wml_client.repository.ModelMetaNames.SOFTWARE_SPEC_UID: sw_spec_id
                        }
-        published_model_details = self.client.repository.store_model(model=TestWMLClientWithKeras.model_path,
+        published_model_details = self.wml_client.repository.store_model(model=TestWMLClientWithKeras.model_path,
                                                                      meta_props=model_props)  # , training_data=digits.data, training_target=digits.target)
-        TestWMLClientWithKeras.model_uid = self.client.repository.get_model_uid(published_model_details)
-        TestWMLClientWithKeras.model_url = self.client.repository.get_model_href(published_model_details)
+        TestWMLClientWithKeras.model_uid = self.wml_client.repository.get_model_uid(published_model_details)
+        TestWMLClientWithKeras.model_url = self.wml_client.repository.get_model_href(published_model_details)
         self.logger.info("Published model ID:" + str(TestWMLClientWithKeras.model_uid))
         self.logger.info("Published model URL:" + str(TestWMLClientWithKeras.model_url))
         self.assertIsNotNone(TestWMLClientWithKeras.model_uid)
@@ -100,35 +113,35 @@ class TestWMLClientWithKeras(unittest.TestCase):
     #         file = open('download_test_uid', 'w')
     #         file.close()
     #
-    #     self.client.repository.download(TestWMLClientWithKeras.model_uid, filename='download_test_url')
-    #     self.assertRaises(WMLClientError, self.client.repository.download, TestWMLClientWithKeras.model_uid,
+    #     self.wml_client.repository.download(TestWMLClientWithKeras.model_uid, filename='download_test_url')
+    #     self.assertRaises(WMLClientError, self.wml_client.repository.download, TestWMLClientWithKeras.model_uid,
     #                       filename='download_test_uid')
 
     def test_04_get_details(self):
         TestWMLClientWithKeras.logger.info("Get model details")
-        details = self.client.repository.get_details(self.model_uid)
+        details = self.wml_client.repository.get_details(self.model_uid)
         TestWMLClientWithKeras.logger.debug("Model details: " + str(details))
         self.assertTrue("KerasModel-gzip" in str(details))
 
     def test_05_create_deployment(self):
         TestWMLClientWithKeras.logger.info("Create deployments")
-        deployment = self.client.deployments.create(TestWMLClientWithKeras.model_uid, meta_props={
-            self.client.deployments.ConfigurationMetaNames.NAME: "Test deployment",self.client.deployments.ConfigurationMetaNames.ONLINE:{}})
+        deployment = self.wml_client.deployments.create(TestWMLClientWithKeras.model_uid, meta_props={
+            self.wml_client.deployments.ConfigurationMetaNames.NAME: "Test deployment",self.wml_client.deployments.ConfigurationMetaNames.ONLINE:{}})
         TestWMLClientWithKeras.logger.info("model_uid: " + self.model_uid)
         TestWMLClientWithKeras.logger.info("Online deployment: " + str(deployment))
         self.assertTrue(deployment is not None)
-        TestWMLClientWithKeras.scoring_url = self.client.deployments.get_scoring_href(deployment)
-        TestWMLClientWithKeras.deployment_uid = self.client.deployments.get_uid(deployment)
+        TestWMLClientWithKeras.scoring_url = self.wml_client.deployments.get_scoring_href(deployment)
+        TestWMLClientWithKeras.deployment_uid = self.wml_client.deployments.get_uid(deployment)
         self.assertTrue("online" in str(deployment))
 
     def test_06_get_deployment_details(self):
         TestWMLClientWithKeras.logger.info("Get deployment details")
-        deployment_details = self.client.deployments.get_details()
+        deployment_details = self.wml_client.deployments.get_details()
         self.assertTrue("Test deployment" in str(deployment_details))
 
     def test_07_get_deployment_details_using_uid(self):
         TestWMLClientWithKeras.logger.info("Get deployment details using uid")
-        deployment_details = self.client.deployments.get_details(TestWMLClientWithKeras.deployment_uid)
+        deployment_details = self.wml_client.deployments.get_details(TestWMLClientWithKeras.deployment_uid)
         self.assertIsNotNone(deployment_details)
 
     def test_08_score(self):
@@ -136,22 +149,22 @@ class TestWMLClientWithKeras(unittest.TestCase):
         x_score_1 = TestWMLClientWithKeras.x_test[23].tolist()
         x_score_2 = TestWMLClientWithKeras.x_test[32].tolist()
         scoring_payload = {
-            self.client.deployments.ScoringMetaNames.INPUT_DATA : [
+            self.wml_client.deployments.ScoringMetaNames.INPUT_DATA : [
                 {
                     'values': [x_score_1, x_score_2]
                 }
             ]
         }
-        predictions = self.client.deployments.score(TestWMLClientWithKeras.deployment_uid, scoring_payload)
+        predictions = self.wml_client.deployments.score(TestWMLClientWithKeras.deployment_uid, scoring_payload)
         self.assertTrue("prediction" in str(predictions))
 
     def test_09_delete_deployment(self):
         TestWMLClientWithKeras.logger.info("Delete deployment")
-        self.client.deployments.delete(TestWMLClientWithKeras.deployment_uid)
+        self.wml_client.deployments.delete(TestWMLClientWithKeras.deployment_uid)
 
     def test_10_delete_model(self):
         TestWMLClientWithKeras.logger.info("Delete model")
-        self.client.repository.delete(TestWMLClientWithKeras.model_uid)
+        self.wml_client.repository.delete(TestWMLClientWithKeras.model_uid)
 
 
 if __name__ == '__main__':
