@@ -450,9 +450,12 @@ class Training(WMLResource):
                     params.pop('space_id')
                 if 'project_id' in params.keys():
                     params.pop('project_id')
+                if 'userfs' in params.keys():
+                    params.pop('userfs')
+
                 response_train_post = requests.post(train_endpoint,
                                                     json=training_configuration_metadata,
-                                                    params= params,
+                                                    params=params,
                                                     headers=self._client._get_headers(),
                                                     verify=False)
 
