@@ -1292,20 +1292,29 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
                 }, axis='columns')
         elif is_ts_metrics:
             pipelines = pipelines.sort_values(
-                by=['Winner'] + get_metrics_names(), ascending=False)
+                by=['Winner'] + [get_metrics_names()[0]], ascending=False)
 
     # note: sometimes backend will not return 'training_' prefix to the metric
     except KeyError:
         pass
 
+    def neg(x):
+        if x is None or (x.__class__.__name__ == 'Series' and len(x) == 0):
+            return x
+
+        if x.__class__.__name__ == 'Series' or type(x) is list:
+            return [neg(a) for a in x]
+        else:
+            return -x
+
     # for columns with _neg_ inside name
     neg_columns = [col for col in pipelines if '_neg_' in col]
-    pipelines[neg_columns] = pipelines[neg_columns].apply(lambda x: -x if x is not None else x)
+    pipelines[neg_columns] = pipelines[neg_columns].apply(lambda x: neg(x))
     pipelines = pipelines.rename(columns={col: col.replace('_neg_', '_') for col in neg_columns})
 
     # for columns with neg_ on beginning of name
     neg_columns = [col for col in pipelines if col.startswith('neg_')]
-    pipelines[neg_columns] = pipelines[neg_columns].apply(lambda x: -x if x is not None else x)
+    pipelines[neg_columns] = pipelines[neg_columns].apply(lambda x: neg(x))
     pipelines = pipelines.rename(columns={col: col[4:] for col in neg_columns})
 
     return pipelines
