@@ -20,7 +20,7 @@ import sys
 import pkg_resources
 import shutil
 import tarfile
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 
 
 INSTANCE_DETAILS_TYPE = u'instance_details_type'
@@ -449,7 +449,7 @@ def extract_mlmodel_from_archive(archive_path, model_uid):
 
 
 def get_model_filename(directory, model_extension):
-    logger = get_logger(__name__)
+    logger = logging.getLogger(__name__)
     model_filepath = None
 
     for file in os.listdir(directory):
