@@ -32,11 +32,12 @@ __all__ = [
 
 
 class WMLClientError(Exception):
-    def __init__(self, error_msg, reason = None):
+    def __init__(self, error_msg, reason=None, logg_messages=True):
         self.error_msg = error_msg
         self.reason = reason
-        logging.getLogger(__name__).warning(self.__str__())
-        logging.getLogger(__name__).debug(str(self.error_msg) + ('\nReason: ' + str(self.reason) if sys.exc_info()[0] is not None else ''))
+        if logg_messages:
+            logging.getLogger(__name__).warning(self.__str__())
+            logging.getLogger(__name__).debug(str(self.error_msg) + ('\nReason: ' + str(self.reason) if sys.exc_info()[0] is not None else ''))
 
     def __str__(self):
         return str(self.error_msg) + ('\nReason: ' + str(self.reason) if self.reason is not None else '')
