@@ -12,8 +12,7 @@ import logging
 
 from diffprivlib.models import GaussianNB
 
-from ibmfl.exceptions import ModelInitializationException, \
-    LocalTrainingException, ModelException
+from ibmfl.exceptions import ModelInitializationException, ModelException
 from ibmfl.model.model_update import ModelUpdate
 from ibmfl.model.sklearn_fl_model import SklearnFLModel
 
@@ -57,8 +56,9 @@ class NaiveBayesFLModel(SklearnFLModel):
 
         self.old_vals = {"theta": None, "sigma": None, "class_count": None}
         self.model_trained = False
+        self.model_type = 'Sklearn-NaiveBayes'
 
-    def fit_model(self, train_data, fit_params=None):
+    def fit_model(self, train_data, fit_params=None, **kwargs):
         """
         Fits current model with provided training data.
 
@@ -198,5 +198,5 @@ class NaiveBayesFLModel(SklearnFLModel):
                                      'Instead they are:' + str(type(model)))
         except Exception as ex:
             raise ModelInitializationException('Model specification was '
-                                               'badly form', str(ex))
+                                               'badly formed. ', str(ex))
         return model
