@@ -9,10 +9,8 @@ irrespective of what has been deposited with the U.S. Copyright Office.
 
 from __future__ import print_function
 import time
-import uuid
 import pickle
 import logging
-from functools import partial
 
 from sklearn.utils.validation import check_is_fitted
 from sklearn.ensemble._hist_gradient_boosting.loss import *
@@ -22,7 +20,6 @@ from sklearn.utils.multiclass import check_classification_targets
 from sklearn.metrics import check_scoring, accuracy_score, r2_score
 from sklearn.utils import check_X_y, check_random_state, check_array
 from sklearn.ensemble._hist_gradient_boosting.grower import TreePredictor
-from sklearn.ensemble._hist_gradient_boosting.common import X_DTYPE, X_BINNED_DTYPE
 
 from ibmfl.util import fl_metrics
 from ibmfl.util import config
@@ -68,15 +65,11 @@ class XGBFLModel(FLModel, ABC):
         self._raw_predictions = None
         self.n_features_ = 0
         self.loss_ = None
-        self._in_fit = False
 
         # Validate and Initialize Model Hyperparameters
         validate_parameters(model_spec)
         init_parameters(self, model_spec)
 
-        # Generate Party-Based UUID (For Model + Metrics Persistence)
-        self.party_uuid = str(uuid.uuid4())
-
     def fit_model(self, train_data, fit_params=None, **kwargs):
         """
         This function is not implemented as model training is not operated
@@ -124,22 +117,18 @@ class XGBFLModel(FLModel, ABC):
 
         # Initialize Prediction Object
         n_samples = x.shape[0]
-        is_binned = getattr(self, '_in_fit', False)
+        preds = np.zeros(shape=(self.n_trees, n_samples))
+
+        # Append Null Model Predictions
+        if self._baseline_prediction is not None:
+            preds += self._baseline_prediction
+        elif self._raw_predictions is not None:
+            preds += self._raw_predictions
 
         # Generate Predictions
-        preds = np.zeros(shape=(self.n_trees, n_samples))
-        if self._baseline_prediction != None:
-            preds += self._baseline_prediction
         for p in self._predictors:
             for k, p_i in enumerate(p):
-                if is_binned:
-                    predict = partial(
-                        p_i.predict_binned,
-                        missing_values_bin_idx=self.bin_mapper_.missing_values_bin_idx_
-                    )
-                else:
-                    predict = p_i.predict
-                preds[k, :] += predict(x)
+                preds[k, :] += p_i.predict(x.astype(np.float64))
 
         return preds
 
@@ -180,8 +169,8 @@ class XGBFLModel(FLModel, ABC):
         """
         if filename is None:
             file = self.model_name if self.model_name else self.model_type
-            filename = '{}_{}.pickle'.format(file, self.party_uuid)
-
+            filename = '{}_{}.pickle'.format(file, time.time())            
+            
         full_path = super().get_model_absolute_path(filename)
 
         # Scikit-Learn Export Demo
@@ -242,8 +231,8 @@ class XGBFLModel(FLModel, ABC):
         """
 
         if type(test_dataset) is tuple:
-            x_test = test_dataset[0].astype(X_DTYPE)
-            y_test = test_dataset[1].astype(Y_DTYPE)
+            x_test = test_dataset[0]
+            y_test = test_dataset[1]
 
             return self.evaluate_model(x_test, y_test)
 
@@ -371,8 +360,8 @@ class XGBClassifierFLModel(XGBFLModel):
         if self.classes_.shape[0] != self.num_classes:
             raise ValueError('Number of classes defined in configuration file '
                              'and the classes derived from the data does not '
-                             'match. Found {0} classes, while config file '
-                             'is defined as {1} classes.'.format(
+                             'match. Found %d classes, while config file '
+                             'is defined as %d classes.'.format(
                              self.classes_.shape[0], self.num_classes))
 
         if self.loss == 'auto':
@@ -457,7 +446,6 @@ class XGBClassifierFLModel(XGBFLModel):
         acc = {}
         if len(self._predictors) > 0:
             y_hat = self.predict(x)
-
             correct = 0
             for i in range(x.shape[0]):
                 if y_hat[i] == y[i]:
@@ -466,6 +454,7 @@ class XGBClassifierFLModel(XGBFLModel):
             acc = {'acc': correct/float(len(y))}
             additional_metrics = fl_metrics.get_eval_metrics_for_classificaton(
                 y, y_hat)
+
             acc = {**acc, **additional_metrics}
             return acc
         else:
