@@ -186,8 +186,6 @@ class Party:
                     returnValue = False
             else:
                 logger.error('Registration Failed: Failure status from aggregator')
-                if response is not None:
-                    logger.error(response.get_data().get('detail', "No Detail Provided"))
         except Exception as ex:
             logger.error("Error occurred during registration" + str(ex))
 
@@ -239,8 +237,6 @@ class Party:
                 logger.info('Listening for commands from Aggregator')
                 self.is_running = True
                 self.initialize_model_config()
-            else:
-                self.stop_connection()
         else:
             logger.info('Party already running.')
 
