@@ -65,7 +65,7 @@ class XGBoostBaseLocalTrainingHandler(LocalTrainingHandler, ABC):
                 logger.info('No model update was provided.')
         except Exception as ex:
             raise LocalTrainingException(
-                'No query information is provided', str(ex))
+                'No query information is provided. '+ str(ex))
 
     def train(self, fit_params=None):
         """
